@@ -23,10 +23,10 @@ flexer.commands.assert_config_exists()
 CONTEXT_SETTINGS = {
     "help_option_names": ["-h", "--help"],
 }
+
 EVENT_SOURCES = [
     "alert-notification",
     "api-hook",
-    "cmp-connector",
     "cmp-connector.alerts",
     "cmp-connector.credentials",
     "cmp-connector.logs",
@@ -36,6 +36,7 @@ EVENT_SOURCES = [
     "cmp-connector.status",
     "cmp-connector.tickets",
     "cmp-resource-notification",
+    "insight",
     "monitor",
     "resource-action",
     "rest-api",
@@ -45,8 +46,8 @@ EVENT_SOURCES = [
     "timer",
     "workflow",
 ]
+
 LANGUAGES = [
-    "go",
     "javascript",
     "python",
     "python3",
@@ -249,17 +250,22 @@ def download(ctx, module_id):
               type=click.Choice(LANGUAGES),
               help="The programming language of your choice")
 @click.argument('module_id')
+@click.option('--handlers',
+              type=click.Path(exists=True, resolve_path=True),
+              required=False,
+              help="Add additional handlers to the module")
 @click.option('--description',
               required=False,
               help="A short description of the module")
 @pass_context
-def update(ctx, module_id, zip, language, description):
+def update(ctx, module_id, zip, language, handlers, description):
     """Update an existing module.
 
     Update the "source_code" or the "description" of an nFlex module.
     """
     try:
-        ctx.nflex.update(module_id, zip, language, description=description)
+        ctx.nflex.update(module_id, zip, language,
+                         handlers=handlers, description=description)
         click.echo("Module %s successfully updated" % module_id, err=True)
 
     except requests.exceptions.RequestException as e:
@@ -287,6 +293,7 @@ def update(ctx, module_id, zip, language, description):
 @click.option('--sync',
               default=False,
               is_flag=True,
+              hidden=True,
               help='Sync the module globally (only for "cmp-connector")')
 @click.option('--zip',
               type=click.Path(exists=True, resolve_path=True),
@@ -305,7 +312,6 @@ def upload(ctx,
                                   description,
                                   event_source,
                                   language,
-                                  sync,
                                   zip)
         click.echo("Module created with ID %s" % module['id'], err=True)
 
