@@ -34,7 +34,6 @@ class NflexClient(object):
                description,
                event_source,
                language,
-               sync,
                zip_file):
         file_type = 'zip' if zip_file else 'inline'
         data = {
@@ -44,7 +43,6 @@ class NflexClient(object):
             'event_source': event_source,
             'source_code': '',
             'language': language,
-            'sync': sync
         }
         if file_type == 'inline':
             mname = "main.{}".format(LANG_EXT.get(language) or "py")
@@ -59,7 +57,8 @@ class NflexClient(object):
 
             return module
 
-    def update(self, module_id, zip_file, language, description=None):
+    def update(self, module_id, zip_file, language,
+               handlers=None, description=None):
         file_type = 'zip' if zip_file else 'inline'
         data = {'file_type': file_type}
         if description is not None:
@@ -68,6 +67,10 @@ class NflexClient(object):
         if language is not None:
             data['language'] = language
 
+        if handlers:
+            with open(handlers, 'r') as hf:
+                data['handlers'] = json.load(hf)
+
         if file_type == 'inline':
             mname = "main.{}".format(LANG_EXT.get(language) or "py")
             data['source_code'] = read_module(mname)
